Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ScanResult ¶
ScanResult represents the result of a port scan
type Scanner ¶
type Scanner struct {
// contains filtered or unexported fields
}
Scanner provides fast TCP port scanning with a worker pool
func NewScanner ¶
NewScanner creates a new port scanner with the specified number of workers
func (*Scanner) GetOpenPortsForHost ¶
GetOpenPortsForHost retrieves all open ports found for a specific host
Click to show internal directories.
Click to hide internal directories.